@@ -12,7 +12,7 @@
 
 namespace Predis\Command\Redis;
 
-use Predis\Command\Command as RedisCommand;
+use Predis\Command\PrefixableCommand as RedisCommand;
 
 class GETDEL extends RedisCommand
 {
@@ -20,4 +20,9 @@ class GETDEL extends RedisCommand
     {
         return 'GETDEL';
     }
+
+    public function prefixKeys($prefix)
+    {
+        $this->applyPrefixForFirstArgument($prefix);
+    }
 }
