@@ -172,11 +172,23 @@ abstract class PredisTestCase extends PHPUnit\Framework\TestCase
             return $this->prepareClusterEndpoints();
         }
 
+        $password = getenv('REDIS_PASSWORD') ?: constant('REDIS_PASSWORD');
+
+        if ($this->isStackTest()) {
+            $port = getenv('REDIS_STACK_SERVER_PORT');
+        } elseif ($this->isUnprotectedTest()) {
+            $port = constant('REDIS_UNPROTECTED_SERVER_PORT');
+            $password = '';
+        } else {
+            $port = constant('REDIS_SERVER_PORT');
+        }
+
         return [
             'scheme' => 'tcp',
             'host' => constant('REDIS_SERVER_HOST'),
-            'port' => ($this->isStackTest()) ? getenv('REDIS_STACK_SERVER_PORT') : constant('REDIS_SERVER_PORT'),
+            'port' => $port,
             'database' => constant('REDIS_SERVER_DBNUM'),
+            'password' => $password,
         ];
     }
 
@@ -477,8 +489,8 @@ abstract class PredisTestCase extends PHPUnit\Framework\TestCase
         }
 
         if (!$this->isSatisfiedRedisModuleVersion($reqVersion, $module)) {
-            $redisModuleVersion = $this->getRedisModuleVersion($module);
-            $module = strtoupper($module);
+            $redisModuleVersion = $this->getRedisModuleVersion($this->modulesMapping[$module]['name']);
+            $redisModuleVersion = str_replace('0', '.', $redisModuleVersion);
 
             $this->markTestSkipped(
                 "Test requires a Redis $module module >= $reqVersion but target module is $redisModuleVersion"
@@ -496,7 +508,7 @@ abstract class PredisTestCase extends PHPUnit\Framework\TestCase
         $currentVersion = $this->getRedisModuleVersion($this->modulesMapping[$module]['name']);
         $versionToCheck = str_replace('.', '', $versionToCheck);
 
-        return $currentVersion >= (int) $versionToCheck;
+        return (int) $currentVersion >= (int) $versionToCheck;
     }
 
     /**
@@ -515,13 +527,7 @@ abstract class PredisTestCase extends PHPUnit\Framework\TestCase
             $this->info = $info;
         }
 
-        if (isset($info['modules'][$module]['ver'])) {
-            $this->redisJsonVersion = $info['modules'][$module]['ver'];
-
-            return $info['modules'][$module]['ver'];
-        }
-
-        return '0';
+        return $info['modules'][$module]['ver'] ?? '0';
     }
 
     /**
@@ -578,8 +584,18 @@ abstract class PredisTestCase extends PHPUnit\Framework\TestCase
             $this->getName(false)
         );
 
-        return isset($annotations['method']['requiresRedisVersion'], $annotations['method']['group'])
-            && !empty($annotations['method']['requiresRedisVersion'])
+        $annotationExists = isset($annotations['method']['requiresRedisVersion']);
+
+        if (!$annotationExists) {
+            foreach ($this->modulesMapping as $module => $configuration) {
+                if (isset($annotations['method'][$configuration['annotation']])) {
+                    $annotationExists = true;
+                }
+            }
+        }
+
+        return $annotationExists
+            && isset($annotations['method']['group'])
             && in_array('connected', $annotations['method']['group'], true)
             && in_array('cluster', $annotations['method']['group'], true);
     }
@@ -600,6 +616,22 @@ abstract class PredisTestCase extends PHPUnit\Framework\TestCase
         && in_array('realm-stack', $annotations['class']['group'], true);
     }
 
+    /**
+     * Check annotations if it's matches to unprotected test scenario.
+     *
+     * @return bool
+     */
+    protected function isUnprotectedTest(): bool
+    {
+        $annotations = TestUtil::parseTestMethodAnnotations(
+            get_class($this),
+            $this->getName(false)
+        );
+
+        return isset($annotations['method']['group'])
+            && in_array('unprotected', $annotations['method']['group'], true);
+    }
+
     /**
      * Parse comma-separated cluster endpoints and convert them into tcp strings.
      *
