@@ -12,6 +12,7 @@
 
 namespace Predis\Command\Redis;
 
+use InvalidArgumentException;
 use Predis\Command\PrefixableCommand;
 
 /**
@@ -84,9 +85,9 @@ class BITOP_Test extends PredisCommandTestCase
     {
         /** @var PrefixableCommand $command */
         $command = $this->getCommand();
-        $actualArguments = ['arg1', 'arg2', 'arg3', 'arg4'];
+        $actualArguments = ['AND', 'arg1', 'arg2', 'arg3', 'arg4'];
         $prefix = 'prefix:';
-        $expectedArguments = ['arg1', 'prefix:arg2', 'prefix:arg3', 'prefix:arg4'];
+        $expectedArguments = ['AND', 'prefix:arg1', 'prefix:arg2', 'prefix:arg3', 'prefix:arg4'];
 
         $command->setArguments($actualArguments);
         $command->prefixKeys($prefix);
@@ -154,6 +155,69 @@ class BITOP_Test extends PredisCommandTestCase
         $this->assertSame(":\x80", $redis->get('key:dst'));
     }
 
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 8.2.0
+     */
+    public function testCanPerformBitwiseONE(): void
+    {
+        $redis = $this->getClient();
+
+        $redis->set('key:src:1', "\x01");
+        $redis->set('key:src:2', "\x02");
+
+        $this->assertSame(1, $redis->bitop('ONE', 'key:dst', 'key:src:1', 'key:src:2'));
+        $this->assertSame("\x03", $redis->get('key:dst'));
+    }
+
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 8.2.0
+     */
+    public function testCanPerformBitwiseDIFF(): void
+    {
+        $redis = $this->getClient();
+
+        $redis->set('key:src:1', "\x01");
+        $redis->set('key:src:2', "\x00");
+        $redis->set('key:src:3', "\x04");
+
+        $this->assertSame(1, $redis->bitop('DIFF', 'key:dst', 'key:src:1', 'key:src:2', 'key:src:3'));
+        $this->assertSame("\x01", $redis->get('key:dst'));
+    }
+
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 8.2.0
+     */
+    public function testCanPerformBitwiseDIFF1(): void
+    {
+        $redis = $this->getClient();
+
+        $redis->set('key:src:1', "\x01");
+        $redis->set('key:src:2', "\x00");
+        $redis->set('key:src:3', "\x04");
+
+        $this->assertSame(1, $redis->bitop('DIFF1', 'key:dst', 'key:src:1', 'key:src:2', 'key:src:3'));
+        $this->assertSame("\x04", $redis->get('key:dst'));
+    }
+
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 8.2.0
+     */
+    public function testCanPerformBitwiseANDOR(): void
+    {
+        $redis = $this->getClient();
+
+        $redis->set('key:src:1', "\x03");
+        $redis->set('key:src:2', "\x02");
+        $redis->set('key:src:3', "\x04");
+
+        $this->assertSame(1, $redis->bitop('ANDOR', 'key:dst', 'key:src:1', 'key:src:2', 'key:src:3'));
+        $this->assertSame("\x02", $redis->get('key:dst'));
+    }
+
     /**
      * @group connected
      * @requiresRedisVersion >= 2.6.0
@@ -181,15 +245,15 @@ class BITOP_Test extends PredisCommandTestCase
     }
 
     /**
-     * @group connected
-     * @requiresRedisVersion >= 2.6.0
+     * @group disconnected
      */
     public function testThrowsExceptionOnInvalidOperation(): void
     {
-        $this->expectException('Predis\Response\ServerException');
-        $this->expectExceptionMessage('ERR syntax error');
+        $this->expectException(InvalidArgumentException::class);
+        $this->expectExceptionMessage('BITOP operation must be one of: AND, OR, XOR, NOT, DIFF, DIFF1, ANDOR, ONE');
 
-        $this->getClient()->bitop('NOOP', 'key:dst', 'key:src:1', 'key:src:2');
+        $command = $this->getCommand();
+        $command->setArguments(['NOOP', 'key:dst', 'key:src:1', 'key:src:2']);
     }
 
     /**
