@@ -12,6 +12,8 @@
 
 namespace Predis\Command\Redis;
 
+use Predis\Command\PrefixableCommand;
+
 /**
  * @group commands
  * @group realm-string
@@ -70,6 +72,23 @@ class SET_Test extends PredisCommandTestCase
         $this->assertSame('OK', $this->getCommand()->parseResponse('OK'));
     }
 
+    /**
+     * @group disconnected
+     */
+    public function testPrefixKeys(): void
+    {
+        /** @var PrefixableCommand $command */
+        $command = $this->getCommand();
+        $actualArguments = ['arg1', 'arg2', 'arg3', 'arg4'];
+        $prefix = 'prefix:';
+        $expectedArguments = ['prefix:arg1', 'arg2', 'arg3', 'arg4'];
+
+        $command->setArguments($actualArguments);
+        $command->prefixKeys($prefix);
+
+        $this->assertSame($expectedArguments, $command->getArguments());
+    }
+
     /**
      * @group connected
      */
@@ -82,6 +101,19 @@ class SET_Test extends PredisCommandTestCase
         $this->assertSame('bar', $redis->get('foo'));
     }
 
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 6.0.0
+     */
+    public function testSetStringValueResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $this->assertEquals('OK', $redis->set('foo', 'bar'));
+        $this->assertSame(1, $redis->exists('foo'));
+        $this->assertSame('bar', $redis->get('foo'));
+    }
+
     /**
      * @group connected
      * @group cluster
