@@ -18,6 +18,9 @@ use Predis\Client;
 use Predis\ClientException;
 use Predis\ClientInterface;
 use Predis\Command\CommandInterface;
+use Predis\Command\Redis\ECHO_;
+use Predis\Command\Redis\PING;
+use Predis\Connection\Parameters;
 use Predis\Response;
 use PredisTestCase;
 use stdClass;
@@ -87,6 +90,11 @@ class PipelineTest extends PredisTestCase
             ->method('readResponse')
             ->willReturn($object);
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $pipeline = new Pipeline(new Client($connection));
 
         $pipeline->ping();
@@ -110,6 +118,11 @@ class PipelineTest extends PredisTestCase
             ->method('readResponse')
             ->willReturn($error);
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $pipeline = new Pipeline(new Client($connection));
 
         $pipeline->ping();
@@ -131,6 +144,11 @@ class PipelineTest extends PredisTestCase
             ->method('readResponse')
             ->willReturn($error);
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $client = new Client($connection, ['exceptions' => false]);
 
         $pipeline = new Pipeline($client);
@@ -199,15 +217,31 @@ class PipelineTest extends PredisTestCase
      */
     public function testExecuteWithFilledBuffer(): void
     {
+        $command1 = new ECHO_();
+        $command1->setArguments(['one']);
+
+        $command2 = new ECHO_();
+        $command2->setArguments(['two']);
+
+        $command3 = new ECHO_();
+        $command3->setArguments(['three']);
+
+        $buffer = $command1->serializeCommand() . $command2->serializeCommand() . $command3->serializeCommand();
         $connection = $this->getMockBuilder('Predis\Connection\NodeConnectionInterface')->getMock();
         $connection
-            ->expects($this->exactly(3))
-            ->method('writeRequest');
+            ->expects($this->once())
+            ->method('write')
+            ->with($buffer);
         $connection
             ->expects($this->exactly(3))
             ->method('readResponse')
             ->willReturnCallback($this->getReadCallback());
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $pipeline = new Pipeline(new Client($connection));
 
         $pipeline->echo('one');
@@ -240,15 +274,37 @@ class PipelineTest extends PredisTestCase
      */
     public function testFlushHandlesPartialBuffers(): void
     {
+        $command1 = new ECHO_();
+        $command1->setArguments(['one']);
+
+        $command2 = new ECHO_();
+        $command2->setArguments(['two']);
+
+        $buffer1 = $command1->serializeCommand() . $command2->serializeCommand();
+
+        $command3 = new ECHO_();
+        $command3->setArguments(['three']);
+
+        $command4 = new ECHO_();
+        $command4->setArguments(['four']);
+
+        $buffer2 = $command3->serializeCommand() . $command4->serializeCommand();
+
         $connection = $this->getMockBuilder('Predis\Connection\NodeConnectionInterface')->getMock();
         $connection
-            ->expects($this->exactly(4))
-            ->method('writeRequest');
+            ->expects($this->exactly(2))
+            ->method('write')
+            ->withConsecutive([$buffer1], [$buffer2]);
         $connection
             ->expects($this->exactly(4))
             ->method('readResponse')
             ->willReturnCallback($this->getReadCallback());
 
+        $connection
+            ->expects($this->exactly(2))
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $pipeline = new Pipeline(new Client($connection));
 
         $pipeline->echo('one');
@@ -265,6 +321,7 @@ class PipelineTest extends PredisTestCase
      */
     public function testSwitchesToMasterWithReplicationConnection(): void
     {
+        $buffer = (new PING())->serializeCommand() . (new PING())->serializeCommand() . (new PING())->serializeCommand();
         $pong = new Response\Status('PONG');
 
         $connection = $this->getMockBuilder('Predis\Connection\Replication\ReplicationInterface')->getMock();
@@ -272,12 +329,17 @@ class PipelineTest extends PredisTestCase
             ->expects($this->once())
             ->method('switchToMaster');
         $connection
-            ->expects($this->exactly(3))
-            ->method('writeRequest');
+            ->expects($this->once())
+            ->method('write')
+            ->with($buffer);
         $connection
             ->expects($this->exactly(3))
             ->method('readResponse')
             ->willReturn($pong);
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
 
         $pipeline = new Pipeline(new Client($connection));
 
@@ -336,14 +398,36 @@ class PipelineTest extends PredisTestCase
      */
     public function testExecuteWithCallableArgumentRunsPipelineInCallable(): void
     {
+        $command1 = new ECHO_();
+        $command1->setArguments(['one']);
+
+        $command2 = new ECHO_();
+        $command2->setArguments(['two']);
+
+        $command3 = new ECHO_();
+        $command3->setArguments(['three']);
+
+        $command4 = new ECHO_();
+        $command4->setArguments(['four']);
+
+        $buffer = $command1->serializeCommand()
+            . $command2->serializeCommand()
+            . $command3->serializeCommand()
+            . $command4->serializeCommand();
+
         $connection = $this->getMockBuilder('Predis\Connection\NodeConnectionInterface')->getMock();
         $connection
-            ->expects($this->exactly(4))
-            ->method('writeRequest');
+            ->expects($this->once())
+            ->method('write')
+            ->with($buffer);
         $connection
             ->expects($this->exactly(4))
             ->method('readResponse')
             ->willReturnCallback($this->getReadCallback());
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
 
         $pipeline = new Pipeline(new Client($connection));
 
@@ -410,6 +494,23 @@ class PipelineTest extends PredisTestCase
         $this->assertSame(['one', 'two', 'three'], $results);
     }
 
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 6.0.0
+     */
+    public function testIntegrationWithFluentInterfaceResp3(): void
+    {
+        $pipeline = $this->getClient(['protocol' => 3])->pipeline();
+
+        $results = $pipeline
+            ->echo('one')
+            ->echo('two')
+            ->echo('three')
+            ->execute();
+
+        $this->assertSame(['one', 'two', 'three'], $results);
+    }
+
     /**
      * @group connected
      */
@@ -512,6 +613,37 @@ class PipelineTest extends PredisTestCase
         $this->assertSame('bar', $results[2]);
     }
 
+    /**
+     * @group connected
+     * @group cluster
+     * @group relay-incompatible
+     * @requiresRedisVersion >= 6.2.0
+     */
+    public function testClusterExecutePipeline(): void
+    {
+        $client = $this->getClient();
+
+        $results = $client->pipeline(function (Pipeline $pipe) {
+            $pipe->set('foo', 'bar');
+            $pipe->set('bar', 'foo');
+            $pipe->set('baz', 'baz');
+            $pipe->get('foo');
+            $pipe->get('bar');
+            $pipe->get('baz');
+        });
+
+        $expectedResults = [
+            new Response\Status('OK'),
+            new Response\Status('OK'),
+            new Response\Status('OK'),
+            'bar',
+            'foo',
+            'baz',
+        ];
+
+        $this->assertSameValues($expectedResults, $results);
+    }
+
     // ******************************************************************** //
     // ---- HELPER METHODS ------------------------------------------------ //
     // ******************************************************************** //
