@@ -14,6 +14,7 @@ namespace Predis\Response\Iterator;
 
 use Predis\Client;
 use Predis\ClientInterface;
+use Predis\Command\RawCommand;
 use Predis\Connection\CompositeStreamConnection;
 use Predis\Connection\NodeConnectionInterface;
 use Predis\Protocol\Text\ProtocolProcessor as TextProtocolProcessor;
@@ -125,6 +126,12 @@ class MultiBulkTupleTest extends PredisTestCase
         $protocol->useIterableMultibulk(true);
 
         $connection = new CompositeStreamConnection($parameters, $protocol);
+        $connection->addConnectCommand(
+            new RawCommand(
+                'AUTH',
+                [getenv('REDIS_PASSWORD') ?: constant('REDIS_PASSWORD')]
+            )
+        );
 
         $client = new Client($connection);
         $client->connect();
